DisplayIntoIter

Struct DisplayIntoIter 

pub struct DisplayIntoIter<'a, T, S>{ /* private fields */ }
Implement Display for cloneable iter sources that yield &T.

It outputs at most limit elements, excluding those from the 5th to the second-to-last one.

Implementations

Source

impl<'a, T, S> DisplayIntoIter<'a, T, S>

pub fn new(items: S) -> Self

pub fn at_most(self, limit: Option<usize>) -> Self

pub fn sep(self, separator: &'a str) -> Self

pub fn braces(self, left: &'a str, right: &'a str) -> Self

pub fn ellipsis(self, s: &'a str) -> Self

pub fn elem(self, prefix: &'a str, suffix: &'a str) -> Self

pub fn show_count(self) -> Self

pub fn limit(&self) -> usize